synthetic_aia_mia.generator — src documentation

# Source code for synthetic_aia_mia.generator

    """Generate synthetic data and evaluate their quality."""

    def identity(x):
        """Identity function. Return the input dataset.

        :param x: Dataset.
        :type x: fetch_data.Dataset
        :return: Return the input x as is.
        :rtype: fetch_data.Dataset
        """
        return x

    def vae(x):
        """Place holder for vae. At the moment, return the input dataset.

        :param x: Dataset.
        :type x: pandas.dataframe
        """
        return x